rockbox.saved-playlists

Persistent named playlists stored in the database, with folder support.

Persistent named playlists stored in the database, with folder support.
raw docstring

add-tracksclj

(add-tracks client playlist-id track-ids)

Append tracks (by id) to a saved playlist.

Append tracks (by id) to a saved playlist.
sourceraw docstring

createclj

(create client {:keys [name] :as input})

Create a saved playlist. input keys: :name (required), :description, :image, :folder-id, :track-ids. Returns the new playlist.

Create a saved playlist. `input` keys: `:name` (required), `:description`,
`:image`, `:folder-id`, `:track-ids`. Returns the new playlist.
sourceraw docstring

create-folderclj

(create-folder client name)

Create a new folder. Returns the folder map.

Create a new folder. Returns the folder map.
sourceraw docstring

deleteclj

(delete client id)

Delete a saved playlist.

Delete a saved playlist.
sourceraw docstring

delete-folderclj

(delete-folder client id)

Delete a folder by id.

Delete a folder by id.
sourceraw docstring

foldersclj

(folders client)

List playlist folders.

List playlist folders.
sourceraw docstring

getclj

(get client id)

Single playlist by id, or nil.

Single playlist by id, or `nil`.
sourceraw docstring

listclj

(list client)
(list client folder-id)

List saved playlists, optionally filtered by folder.

List saved playlists, optionally filtered by folder.
sourceraw docstring

playclj

(play client playlist-id)

Load a saved playlist into the queue and start playing.

Load a saved playlist into the queue and start playing.
sourceraw docstring

remove-trackclj

(remove-track client playlist-id track-id)

Remove a single track from a saved playlist.

Remove a single track from a saved playlist.
sourceraw docstring

track-idsclj

(track-ids client playlist-id)

Ordered track ids for a saved playlist.

Ordered track ids for a saved playlist.
sourceraw docstring

updateclj

(update client id {:keys [name] :as input})

Update a saved playlist's metadata. input: :name (required), :description, :image, :folder-id. Returns the client.

Update a saved playlist's metadata. `input`: `:name` (required),
`:description`, `:image`, `:folder-id`. Returns the client.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries