rockbox.smart-playlists

Smart (rule-based) playlists and listening stats.

Smart (rule-based) playlists and listening stats.
raw docstring

createclj

(create client {:keys [name rules] :as input})

Create a smart playlist. input keys: :name (required), :rules (required — string or data), :description, :image, :folder-id.

Create a smart playlist. `input` keys: `:name` (required), `:rules`
(required — string or data), `:description`, `:image`, `:folder-id`.
sourceraw docstring

deleteclj

(delete client id)
source

getclj

(get client id)
source

listclj

(list client)
source

playclj

(play client id)
source

record-playedclj

(record-played client track-id)

Record that a track was played.

Record that a track was played.
sourceraw docstring

record-skippedclj

(record-skipped client track-id)

Record that a track was skipped.

Record that a track was skipped.
sourceraw docstring

track-idsclj

(track-ids client id)

Resolve a smart playlist to the matching track ids right now.

Resolve a smart playlist to the matching track ids right now.
sourceraw docstring

track-statsclj

(track-stats client track-id)

Listening stats for a track, or nil.

Listening stats for a track, or `nil`.
sourceraw docstring

updateclj

(update client id {:keys [name rules] :as input})

Update a smart playlist. input keys: :name, :rules, ...

Update a smart playlist. `input` keys: `:name`, `:rules`, ...
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries